# Changelog

## [0.15.0](https://github.com/taoq-ai/ziran/compare/v0.14.0...v0.15.0) (2026-03-20)


### Features

* add --dry-run mode and config validation to CLI ([76611f7](https://github.com/taoq-ai/ziran/commit/76611f7c9a8149a9575c431f08bc802c8fbef8f7))
* add campaign checkpoint/resume support ([9c79f2e](https://github.com/taoq-ai/ziran/commit/9c79f2e0b7bc7031acc00be5acd13f9befa83658))

## [0.14.0](https://github.com/taoq-ai/ziran/compare/v0.13.0...v0.14.0) (2026-03-20)


### Features

* add MCP write/git and broader financial patterns to classifier ([#187](https://github.com/taoq-ai/ziran/issues/187)) ([9d3197d](https://github.com/taoq-ai/ziran/commit/9d3197d0c4a6feb576de58c0285a43370e77a257)), closes [#163](https://github.com/taoq-ai/ziran/issues/163)
* make detector pipeline configurable and extensible ([#189](https://github.com/taoq-ai/ziran/issues/189)) ([71c8028](https://github.com/taoq-ai/ziran/commit/71c80289f02d40f08c18dc062be0821346452fa5)), closes [#121](https://github.com/taoq-ai/ziran/issues/121)


### Performance Improvements

* pre-compile regex patterns in static analysis checks ([#186](https://github.com/taoq-ai/ziran/issues/186)) ([eb2b25a](https://github.com/taoq-ai/ziran/commit/eb2b25afb7a394b85d595c9fb1bb9db64901376f)), closes [#113](https://github.com/taoq-ai/ziran/issues/113)
